;;; new.emacs.el --- W32 GNU Emacs Initialization File

;; Copyright (C) 2000 by Mark Ayers

;; Author:  Mark Ayers <n2s@linuxfreak.com>
;; Keywords: init

;;; Commentary:

;; A complete rework of my original mess of an emacs init file.  This is
;; specialized for W32 Gnu Emacs at work. I have decided not to develop a
;; comprehensive Emacs init for my home GNU/Linux machine and my work W2K
;; Server machine.

;;; History:

;; development begun 2000-08-18
;; Monday, August 14, 2000: Full Moon 10:11pm (PDT)
;; Aug 18, 2000: Sunrise 6:09am (PDT), sunset 8:13pm (PDT) at 48.0N, 122.0W
;; Friday, September 22, 2000: Autumnal Equinox 10:27am (PDT)

;;; Code:

;;-- load path
(defun set-load-path ()
  (set 'load-path (cons (expand-file-name "~/lisp") load-path))
  ;; add others here
  (message "Load path set."))
(set-load-path)

;;-- emacs visual appearance
(defun set-visual-preferences ()
  "Setup visual preferences."
  (set 'frame-title-format '("Emacs "	 " -- " " %b"))
  (set 'default-frame-alist '((top . 25) (left . 50) 
			      (width . 80) (height . 55)
			      (background-color . "DarkSlateGrey")
			      (foreground-color . "Wheat")
			      (menu-bar-lines . 1)))
  ;;(set-default-font 
  ;; "-*-Lucida Console-normal-r-*-*-13-97-96-96-c-*-iso8859-1")
  (message "Visual preferences are set."))
(set-visual-preferences)

;;-- personalization variables
(defun set-personal-variables ()
  "Set personal variables."
  ;; do stuff here
  (set 'user-full-name "Mark Ayers")
  (set 'user-mail-address "n2s@LinuxFreak.com")
  (message "Personal variables set."))
(set-personal-variables)

;;-- hacks for libraries shipped with emacs

;; font-lock hacks
(defun set-font-lock-hacks ()
  "Set font-lock hacks."
  (global-font-lock-mode)
  ;; other stuff
  (message "Font-lock hacks set."))
(set-font-lock-hacks)

;; calendar hacks
(defun set-calendar-hacks ()
  "Set calendar hacks."
  (add-hook 'diary-hook 'appt-make-list)
  (display-time)			; for appt hacks
  (set 'calendar-daylight-time-zone-name "PDT")
  (set 'calendar-latitude '[48 0 north])
  (set 'calendar-longitude '[122 0 west])
  (set 'calendar-standard-time-zone-name "PST")
  (set 'european-calendar-style t)
  ;;(set 'view-calendar-holidays-initially t)
  (set 'view-diary-entries-initially t)
  (message "Calendar hacks set."))
(set-calendar-hacks)

;; emacs print appearance
(defun set-printer-preferences ()	; ps-print settings
  "Setup print preferences."
  (set 'ps-font-size '(10 . 10))	; body font size
  (set 'ps-header-font-size '(6 . 6))	; don't need big fonts here
  (set 'ps-header-title-font-size '(7 . 7)) ; don't need big fonts here
  (set 'ps-line-number nil)		; might turn 'em on sometimes
  (set 'ps-lpr-command "print")		; send it through print
  (set 'ps-print-header-frame nil)	; don't need to be fancy
  (set 'ps-printer-name "LPT1")		; start with the workgroup printer
  (message "Printing preferences are set."))
(set-printer-preferences)

;;-- hacks for libraries not shipped with emacs

;;-- utility functions

;; switches between LPT1 and LPT2
(defun change-printer ()
  "*Change printer switch."
  (interactive "*")
  (if (not (equal ps-printer-name "LPT1"))
      (list (set 'ps-printer-name "LPT1") ; NET USE for workgroup LJ5SI
	    (set 'ps-spool-duplex nil)
	    (message "Printer set to LPT1"))
    (list (set 'ps-printer-name "LPT2") ; NET USE for big Xerox 4230 MRP
	  (set 'ps-spool-duplex t)	; duplex capable
	  (message "Printer set to LPT2"))))

;;-- key mappings
(global-set-key [(f11)] 'copy-region-as-kill) ; copy
(global-set-key [(f10)] 'ps-print-buffer) ; print

;;-- save state of work while limiting a bit
(desktop-load-default)
(add-hook 'kill-emacs-hook 
	  '(lambda ()
	     (desktop-truncate search-ring 3)
	     (desktop-truncate regexp-search-ring 3)))
(desktop-read)

(calendar)
;;; new.emacs.el ends here
